<?php

namespace Drupal\athenapdf_api;

use Drupal\Core\Url;

/**
 * Interface AthenaPdfApiConverterInterface.
 */
interface AthenaPdfConverterInterface {

  /**
   * Generates a pdf from a given url.
   *
   * @param string $url
   *   An absolute URL to generate the PDF from.
   *
   * @return string
   *   Path to the output file.
   *
   * @throws \GuzzleHttp\Exception\GuzzleException
   */
  public function urlToPdf($url);

  /**
   * Returns a pdf generated from given markup.
   *
   * @param string $markup
   *   The HTML markup to generate the DPF from.
   *
   * @return string
   *   Path to the output file.
   *
   * @throws \GuzzleHttp\Exception\GuzzleException
   */
  public function markupToPdf($markup);

  /**
   * Returns the markup stored under the given id.
   *
   * @param String $markup
   *   The markup to save under the given id.
   *
   * @return String
   *   The id under which the item is available..
   */
  public function addItem(String $markup);

  /**
   * Returns the markup stored under the given id and removes it.
   *
   * @param String $id
   *   The unique id.
   *
   * @return String|NULL
   *   The markup or NULL.
   */
  public function burnAfterReading(String $id);

}
