<?php

namespace Drupal\Tests\athenapdf_api\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Simple test to ensure that main page loads with module enabled.
 *
 * @group athenapdf_api
 */
class BrowserTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['athenapdf_api'];

  /**
   * The converter service.
   *
   * @var \Drupal\athenapdf_api\AthenaPdfConverterInterface
   */
  protected $converter;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->converter = $this->container->get('athenapdf_api.converter');
  }

  /**
   * Tests that the home page loads with a 200 response.
   */
  public function testLoad() {
    $this->drupalGet(Url::fromRoute('<front>'));
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Tests that the home page loads with a 200 response.
   */
  public function testController() {
    $markup = '<html lang="en"><body>Testing</body></html>';
    $id = $this->converter->addItem($markup);
    $uri = "internal:/athenapdf_api/markup/$id";

    $this->drupalGet(Url::fromUri($uri));
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->responseContains($markup);

    // The item should be burnt after reading.
    $this->drupalGet(Url::fromUri($uri));
    $session = $this->assertSession();
    $session->statusCodeEquals(404);

    // TODO: Move the code below to a kernel test.

    // TODO: Add a testing docker-compose file with the service.

//    try {
//      $this->converter->markupToPdf($markup);
//    } catch (ServerException $e) {
//      // Server exceptions are fine.
//    }
//
//    $finfo = finfo_open(FILEINFO_MIME_TYPE);
//    $pdf = $this->converter->urlToPdf('https://drupal.org');
//    $this->assert(finfo_file($finfo, $pdf) === 'application/pdf');
  }

}
